.. _generator:

Generator
=========

.. _generator_types:
.. toctree::
   :maxdepth: 1
   :caption: Generator Types

   generators/invoice_payment
   generators/invoice_item
   generators/offer_item
   generators/project_expense